#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.base.interfaces import IBaseContent
from onf_website.reference.location.interfaces.territory import ITerritoryTable, ITerritory
from pyams_skin.interfaces.viewlet import IWidgetTitleViewletManager
from pyams_skin.layer import IPyAMSLayer
from pyams_zmi.layer import IAdminLayer

# import packages
from onf_website.reference.location.territory import Territory
from onf_website.reference.zmi.table import ReferenceTableContentsTable
from pyams_form.form import AJAXAddForm, AJAXEditForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.viewlet.toolbar import ToolbarAction
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminDialogAddForm, AdminDialogEditForm
from pyramid.view import view_config
from z3c.form import field

from onf_website import _


@viewlet_config(name='add-territory.action', context=ITerritoryTable, layer=IAdminLayer,
                manager=IWidgetTitleViewletManager, view=ReferenceTableContentsTable, permission='onf.ManageSiteRoot')
class TerritoryAddAction(ToolbarAction):
    """Territory add action"""

    label = _("Add territory")

    url = 'add-territory.html'
    modal_target = True


@pagelet_config(name='add-territory.html', context=ITerritoryTable, layer=IPyAMSLayer, permission='onf.ManageSiteRoot')
class TerritoryAddForm(AdminDialogAddForm):
    """Territory add form"""

    legend = _("Adding new territory")

    fields = field.Fields(ITerritory).omit('__parent__')
    ajax_handler = 'add-territory.json'
    edit_permission = 'onf.ManageSiteRoot'

    def create(self, data):
        return Territory()

    def add(self, object):
        self.context[object.__name__] = object

    def nextURL(self):
        return 'contents.html'


@view_config(name='add-territory.json', context=ITerritoryTable, request_type=IPyAMSLayer,
             permission='onf.ManageSiteRoot', renderer='json', xhr=True)
class TerritoryAJAXAddForm(AJAXAddForm, TerritoryAddForm):
    """Territory add form, JSON renderer"""


@pagelet_config(name='properties.html', context=ITerritory, layer=IPyAMSLayer, permission='system.view')
class TerritoryEditForm(AdminDialogEditForm):
    """Territory edit form"""

    legend = _("Edit territory properties")

    fields = field.Fields(ITerritory).omit('__parent__', '__name__')
    ajax_handler = 'properties.json'
    edit_permission = 'onf.ManageSiteRoot'


@view_config(name='properties.json', context=ITerritory, request_type=IPyAMSLayer,
             permission='onf.ManageSiteRoot', renderer='json', xhr=True)
class TerritoryAJAXEditForm(AJAXEditForm, TerritoryEditForm):
    """Territory edit form, JSON renderer"""

    def get_ajax_output(self, changes):
        if 'title' in changes.get(IBaseContent, ()):
            return {'status': 'reload',
                    'location': 'contents.html'}
        else:
            return super(TerritoryAJAXEditForm, self).get_ajax_output(changes)
