#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.base.interfaces import IBaseContent
from onf_website.reference.location.interfaces.unit import IUnitTable, IUnit
from pyams_skin.interfaces.viewlet import IWidgetTitleViewletManager
from pyams_skin.layer import IPyAMSLayer
from pyams_zmi.layer import IAdminLayer

# import packages
from onf_website.reference.location.unit import Unit
from onf_website.reference.zmi.table import ReferenceTableContentsTable
from pyams_form.form import AJAXAddForm, AJAXEditForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.viewlet.toolbar import ToolbarAction
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminDialogAddForm, AdminDialogEditForm
from pyramid.view import view_config
from z3c.form import field

from onf_website import _


@viewlet_config(name='add-unit.action', context=IUnitTable, layer=IAdminLayer,
                manager=IWidgetTitleViewletManager, view=ReferenceTableContentsTable, permission='onf.ManageSiteRoot')
class UnitAddAction(ToolbarAction):
    """Unit add action"""

    label = _("Add territorial unit")

    url = 'add-unit.html'
    modal_target = True


@pagelet_config(name='add-unit.html', context=IUnitTable, layer=IPyAMSLayer, permission='onf.ManageSiteRoot')
class UnitAddForm(AdminDialogAddForm):
    """Unit add form"""

    legend = _("Adding new territorial unit")

    fields = field.Fields(IUnit).omit('__parent__')
    ajax_handler = 'add-unit.json'
    edit_permission = 'onf.ManageSiteRoot'

    def create(self, data):
        return Unit()

    def add(self, object):
        self.context[object.__name__] = object

    def nextURL(self):
        return 'contents.html'


@view_config(name='add-unit.json', context=IUnitTable, request_type=IPyAMSLayer,
             permission='onf.ManageSiteRoot', renderer='json', xhr=True)
class UnitAJAXAddForm(AJAXAddForm, UnitAddForm):
    """Unit add form, JSON renderer"""


@pagelet_config(name='properties.html', context=IUnit, layer=IPyAMSLayer, permission='system.view')
class UnitEditForm(AdminDialogEditForm):
    """Unit edit form"""

    legend = _("Edit territorial unit properties")

    fields = field.Fields(IUnit).omit('__parent__', '__name__')
    ajax_handler = 'properties.json'
    edit_permission = 'onf.ManageSiteRoot'


@view_config(name='properties.json', context=IUnit, request_type=IPyAMSLayer,
             permission='onf.ManageSiteRoot', renderer='json', xhr=True)
class UnitAJAXEditForm(AJAXEditForm, UnitEditForm):
    """Unit edit form, JSON renderer"""

    def get_ajax_output(self, changes):
        if 'title' in changes.get(IBaseContent, ()):
            return {'status': 'reload',
                    'location': 'contents.html'}
        else:
            return super(UnitAJAXEditForm, self).get_ajax_output(changes)
