#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.shared.news.interfaces import INewsManager, IWfNewsEvent
from pyams_i18n.interfaces import II18n
from pyams_skin.interfaces.viewlet import IWidgetTitleViewletManager
from pyams_skin.layer import IPyAMSLayer
from pyams_zmi.layer import IAdminLayer

# import packages
from onf_website.shared.common.zmi import SharedContentAddForm, SharedContentAJAXAddForm
from onf_website.shared.news import WfNewsEvent, NewsEvent
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.interfaces import IContentTitle
from pyams_skin.viewlet.toolbar import ToolbarAction
from pyams_utils.adapter import adapter_config, ContextRequestViewAdapter
from pyams_viewlet.viewlet import viewlet_config
from pyramid.view import view_config
from zope.interface import Interface

from onf_website import _


@adapter_config(context=(IWfNewsEvent, IPyAMSLayer, Interface), provides=IContentTitle)
class NewsEventTitleAdapter(ContextRequestViewAdapter):
    """News event title adapter"""

    @property
    def title(self):
        translate = self.request.localizer.translate
        return translate(_("News event « {title} »")).format(
            title=II18n(self.context).query_attribute('short_name', request=self.request))


@viewlet_config(name='add-shared-event.action', context=INewsManager, layer=IAdminLayer,
                manager=IWidgetTitleViewletManager, permission='onf.CreateContent', weight=1)
class NewsEventAddAction(ToolbarAction):
    """News event adding action"""

    label = _("Add news event")
    url = 'add-shared-content.html'
    modal_target = True


@pagelet_config(name='add-shared-content.html', context=INewsManager, layer=IPyAMSLayer, permission='onf.CreateContent')
class NewsEventAddForm(SharedContentAddForm):
    """News event add form"""

    legend = _("Add new news event")
    icon_css_class = 'fa fa-fw fa-newspaper-o'

    content_class = NewsEvent
    wf_content_class = WfNewsEvent


@view_config(name='add-shared-content.json', context=INewsManager, request_type=IPyAMSLayer,
             permission='onf.CreateContent', renderer='json', xhr=True)
class NewsEventAJAXAddForm(SharedContentAJAXAddForm, NewsEventAddForm):
    """News event add form, JSON renderer"""
